@@ -1,11 +1,12 @@
 package org.ovirt.engine.core.bll;
 
+import org.ovirt.engine.core.bll.context.EngineContext;
 import org.ovirt.engine.core.common.queries.QosQueryParameterBase;
 
 public class GetAllQosByStoragePoolIdAndTypeQuery extends QosQueryBase {
 
-    public GetAllQosByStoragePoolIdAndTypeQuery(QosQueryParameterBase parameters) {
-        super(parameters);
+    public GetAllQosByStoragePoolIdAndTypeQuery(QosQueryParameterBase parameters, EngineContext engineContext) {
+        super(parameters, engineContext);
     }
 
     @Override
