@@ -48,7 +48,7 @@ import org.ovirt.engine.ui.uicommonweb.validation.HostnameValidation;
 import org.ovirt.engine.ui.uicommonweb.validation.IValidation;
 import org.ovirt.engine.ui.uicommonweb.validation.IntegerValidation;
 import org.ovirt.engine.ui.uicommonweb.validation.LengthValidation;
-import org.ovirt.engine.ui.uicommonweb.validation.NoSpacesValidation;
+import org.ovirt.engine.ui.uicommonweb.validation.NoTrimmingWhitespacesValidation;
 import org.ovirt.engine.ui.uicommonweb.validation.NotEmptyValidation;
 import org.ovirt.engine.ui.uicommonweb.validation.SpecialAsciiI18NOrNoneValidation;
 import org.ovirt.engine.ui.uicompat.ConstantsManager;
@@ -1140,7 +1140,7 @@ public abstract class HostModel extends Model implements HasValidatedTabs {
         }
         setValidTab(TabName.CONSOLE_TAB, getConsoleAddress().getIsValid());
 
-        getKernelCmdline().validateEntity(new IValidation[] { new NoSpacesValidation() });
+        getKernelCmdline().validateEntity(new IValidation[] { new NoTrimmingWhitespacesValidation() });
         setValidTab(TabName.KERNEL_TAB, getKernelCmdline().getIsValid());
 
         getDataCenter().validateSelectedItem(new IValidation[] { new NotEmptyValidation() });
